Crate kahlo

Crate kahlo 

kahlo is a software drawing library designed for speed and flexibility.

The main goal for kahlo is to provide fast drawing of simple 2D shapes and paths onto Rgba32 surfaces. Contrary to other libraries such as tiny-skia, functionality is aimed more at blitting than rendering paths.

Many operations in kahlo will use an optimized SIMD implementation, if present and supported on the current platform, though all operations have fallback SISD implementations. Note that the SISD implementations are mostly present for automated testing and verification purposes, and are written for clarity over speed.

Re-exports

pub use colour as color;

Modules

_accelerated
Accelerated kahlo operations
colour
Colour-related functionality.
formats
Pixel format definitions.
math
Types and operations for 2D mathematics.
palette
Standard groups of named colours
prelude
Trait re-exports.

Structs

Bitmap
Owned bitmap with static pixel format information.
BitmapMut
Mutably borrowed bitmap with static pixel format information.
BitmapRef
Borrowed bitmap with static pixel format information.

Type Aliases

Alphamap
Helper type alias for an A8 bitmap.
PremultRgbaBitmap
Helper type alias for a Rgba32 bitmap with premultiplied alpha.
RgbaBitmap
Helper type alias for a Rgba32 bitmap.